command

package
v0.0.0-...-74262d2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 23, 2022 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var RootCommand = &cobra.Command{
	Use:     "mygobb",
	Short:   "MyGoBB is a next generation simple and fast bulletin board written in Go.",
	Long:    "MyGoBB is a next generation simple and fast bulletin board written in Go.",
	Run:     run,
	Version: constants.Version,
}

RootCommand is the root command of mygobb

Functions

func Execute

func Execute()

Execute registers the RootCommand

func LoadDatabase

func LoadDatabase() (err error)

LoadDatabase loads the database and runs any migrations we need to

Types

This section is empty.

Jump to