Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var RootCommand = &cobra.Command{ Use: "mygobb", Short: "MyGoBB is a next generation simple and fast bulletin board written in Go.", Long: "MyGoBB is a next generation simple and fast bulletin board written in Go.", Run: run, Version: constants.Version, }
RootCommand is the root command of mygobb
Functions ¶
func LoadDatabase ¶
func LoadDatabase() (err error)
LoadDatabase loads the database and runs any migrations we need to
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.